@@ -25,15 +25,17 @@ class CMakeListsBuilder(object):
         self.include_directories(project.target.include_directories)
         for package in self.test_packages_with_sources(project.test):
             self.build_package_recipe(package)
+        for package in self.bit_packages_with_sources(project.test):
+            self.build_package_recipe(package)
         for test in project.test.test_suites:
             self.add_executable(
                 test.name,
                 [test.main],
                 [self.object_library_name(package.path) for package in self.target_packages_with_sources(project.target)] +
-                [self.object_library_name(package.path) for package in self.bit_packages_with_sources(project.target)] +
-                [self.object_library_name(package.path) for package in self.bit_packages_with_sources(project.test)] +
                 [self.object_library_name(package.path) for package in self.test_packages_with_sources(project.test)] +
-                [self.object_library_name(package.path) for package in self.test_packages_with_sources(test)]
+                [self.object_library_name(package.path) for package in self.test_packages_with_sources(test)] +
+                [self.object_library_name(package.path) for package in self.bit_packages_with_sources(project.test)] +
+                [self.object_library_name(package.path) for package in self.bit_packages_with_sources(project.target)]
             )
             self.set_target_properties(test.name, 'COMPILE_FLAGS', project.test.cflags + test.cflags)
             self.target_include_directories(
@@ -43,7 +45,7 @@ class CMakeListsBuilder(object):
             )
             self.target_link_libraries(test.name, project.test.libraries + test.libraries)
         if project.test.test_suites:
-            self.add_custom_target('tests', 'echo "> Done', [test.name for test in project.test.test_suites])
+            self.add_custom_target('tests', 'echo ""', [test.name for test in project.test.test_suites])
         return self.contents
 
     def target_packages_with_sources(self, target):
@@ -59,6 +61,7 @@ class CMakeListsBuilder(object):
         package_library_name = self.object_library_name(package.path)
         self.add_object_library(package_library_name, package.sources)
         self.set_target_properties(package_library_name, 'COMPILE_FLAGS', package.cflags)
+        self.target_include_directories(package_library_name, package.include_directories)
 
     def object_library_name(self, package_path):
         return f'{package_path.replace("/", "_")}_object_library'
@@ -105,7 +108,7 @@ class CMakeListsBuilder(object):
 
     def add_custom_target(self, target, command, depends):
         self.contents += f'add_custom_target({target}\n' \
-                         f'    COMMAND {command}"\n' \
+                         f'    COMMAND {command}\n' \
                          f'    DEPENDS {" ".join(depends)}\n' \
                          f')\n'
 
