@@ -6,14 +6,14 @@ from cpm.api.install import install_project_bits
 from cpm.api.result import OK
 from cpm.api.result import FAIL
 from cpm.domain.install_service import BitNotFound
-from cpm.domain.project_loader import NotAChromosProject
+from cpm.domain.project.project_descriptor_parser import NotACpmProject
 from cpm.infrastructure.http_client import HttpConnectionError
 
 
 class TestApiInstall(unittest.TestCase):
     def test_bit_install_fails_when_current_directory_is_not_a_chromos_project(self):
         install_service = mock.MagicMock()
-        install_service.install.side_effect = NotAChromosProject
+        install_service.install.side_effect = NotACpmProject
 
         result = install_bit(install_service, 'cest')
 
@@ -60,11 +60,11 @@ class TestApiInstall(unittest.TestCase):
         result = install_project_bits(install_service)
 
         assert result.status_code == OK
-        install_service.install_project_bits.assert_called_once()
+        install_service.install_all.assert_called_once()
 
     def test_bit_install_of_all_bits_in_project_fails_when_current_directory_is_not_a_chromos_project(self):
         install_service = mock.MagicMock()
-        install_service.install_project_bits.side_effect = NotAChromosProject
+        install_service.install_all.side_effect = NotACpmProject
 
         result = install_project_bits(install_service)
 
@@ -72,7 +72,7 @@ class TestApiInstall(unittest.TestCase):
 
     def test_bit_install_of_all_bits_in_project_fails_when_http_connection_fails(self):
         install_service = mock.MagicMock()
-        install_service.install_project_bits.side_effect = HttpConnectionError
+        install_service.install_all.side_effect = HttpConnectionError
 
         result = install_project_bits(install_service)
 
@@ -80,7 +80,7 @@ class TestApiInstall(unittest.TestCase):
 
     def test_bit_install_of_all_bits_in_project_fails_when_one_bit_does_not_exist(self):
         install_service = mock.MagicMock()
-        install_service.install_project_bits.side_effect = BitNotFound
+        install_service.install_all.side_effect = BitNotFound
 
         result = install_project_bits(install_service)
 
